==> nextcloud-app-richdocuments-1.1.25-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/richdocuments/l10n/pt_BR.js <==
OC.L10N.register(
    "richdocuments",
    {
    "Saving..." : "Salvando...",
    "Download this revision" : "Baixar esta revusão",
    "Restore this revision" : "Restaurar esta revisão",
    "Latest revision" : "Última revisão",
    "More versions..." : "Mais versões...",
    "Just now" : "Agora",
    "Failed to revert the document to older version" : "Falha ao reverter o documento para a versão anterior",
    "Save" : "Salvar",
    "Loading documents..." : "Carregando documentos...",
    "Edit" : "Editar",
    "View" : "Visualizar",
    "Document" : "Documento",
    "Spreadsheet" : "Planilha de Cálculo",
    "Presentation" : "Apresentação",
    "Could not create file" : "Não foi possível criar o arquivo",
    "New Document.odt" : "Novo Documento.odt",
    "New Spreadsheet.ods" : "Novo Planilhadecalculo.ods",
    "New Presentation.odp" : "Nova Apresentação.odp",
    "New Document.docx" : "Novo Documento.docx",
    "New Spreadsheet.xlsx" : "Nova Planilha.xlsx",
    "New Presentation.pptx" : "Nova Apresentação.pptx",
    "Can't create document" : "Impedido de criar documentos",
    "Saved" : "Salvo",
    "Saved with error: Collabora Online should use the same protocol as the server installation." : "Salvo com erro: Collabora Online deve usar o mesmo protocolo que a instalação do servidor.",
    "Collabora Online" : "Collabora Online",
    "Collabora Online server" : "Servidor Collabora Online",
    "URL (and port) of the Collabora Online server that provides the editing functionality as a WOPI client." : "URL (e porta) do servidor Collabora Online que fornece a funcionalidade de edição como um cliente WOPI.",
    "Apply" : "Aplicar",
    "Use OOXML by default for new files" : "Use OOXML por padrão para novos arquivos",
    "Wrong password. Please retry." : "Senha errada. Por favor tente novamente.",
    "Password" : "Senha",
    "OK" : "OK",
    "Guest %s" : "Convidado %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Este link expirou ou nunca existiu. Por favor faça contato com a pessoa que compartilhou este link com você para maiores detalhes."
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-app-richdocuments-1.12.31-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/richdocuments/l10n/pt_BR.js <==
OC.L10N.register(
    "richdocuments",
    {
    "Saving..." : "Salvando...",
    "Download this revision" : "Baixar esta revisão",
    "Restore this revision" : "Restaurar esta revisão",
    "Latest revision" : "Última revisão",
    "More versions..." : "Mais versões...",
    "Just now" : "Agora",
    "Failed to revert the document to older version" : "Falha ao reverter o documento para a versão anterior",
    "Save" : "Salvar",
    "Loading documents..." : "Carregando documentos...",
    "Edit" : "Editar",
    "New Document" : "Novo Documento",
    "New Spreadsheet" : "Nova Planilha",
    "New Presentation" : "Nova Apresentação",
    "Could not create file" : "Não foi possível criar o arquivo",
    "New Document.odt" : "Novo Documento.odt",
    "New Spreadsheet.ods" : "Novo Planilha.ods",
    "New Presentation.odp" : "Nova Apresentação.odp",
    "New Document.docx" : "Novo Documento.docx",
    "New Spreadsheet.xlsx" : "Nova Planilha.xlsx",
    "New Presentation.pptx" : "Nova Apresentação.pptx",
    "Can't create document" : "Não foi possível criar o documento",
    "Saved" : "Salvo",
    "Saved with error: Collabora Online should use the same protocol as the server installation." : "Salvo com erro: Collabora Online deve usar o mesmo protocolo que a instalação do servidor.",
    "Collabora Online" : "Collabora Online",
    "Collabora Online server" : "Servidor Collabora Online",
    "URL (and port) of the Collabora Online server that provides the editing functionality as a WOPI client." : "URL (e porta) do servidor Collabora Online que fornece a funcionalidade de edição como um cliente WOPI.",
    "Apply" : "Aplicar",
    "Use OOXML by default for new files" : "Use OOXML por padrão para novos arquivos",
    "Wrong password. Please retry." : "Senha errada. Por favor tente novamente.",
    "Password" : "Senha",
    "OK" : "OK",
    "Guest %s" : "Convidado %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Este link expirou ou nunca existiu. Por favor contacte a pessoa que compartilhou este link com você para maiores detalhes."
},
"nplurals=2; plural=(n > 1);");
